@@ -1,14 +1,15 @@
 #!/usr/bin/env python
 # vim: set fileencoding=utf8:
 """
-initialization django-object-permission
+Watch modification of any type of field in Django model
 
-Add this backend to your ``AUTHENTICATION_BACKENDS`` like below::
+Usage:
+    from observer import watch
+    watcher = watch(model_instance, field_name, callback_function)
+
+Warning:
+    Call ``observer.unwatch_all()`` in ``tearDown`` method of TestCase in django's test just in case
 
-    AUTHENTICATION_BACKENDS = (
-        'django.contrib.auth.backends.ModelBackend',
-        'object_permission.backends.ObjectPermBackend',
-    )
 
 AUTHOR:
     lambdalisue[Ali su ae] (lambdalisue@hashnote.net)
@@ -32,18 +33,21 @@ License:
 __AUTHOR__ = "lambdalisue (lambdalisue@hashnote.net)"
 from django.conf import settings
 
-from watcher.complex import ComplexWatcher
+from watchers import Watcher
+from watchers import ComplexWatcher
 
 __all__ = ['watch']
 
-settings.OBSERVER_DEFAULT_WATCHER = \
-        getattr(settings, 'OBSERVER_DEFAULT_WATCHER', ComplexWatcher)
-
 def watch(obj, attr, callback):
     """Shortcut method for creating Watcher instance
     
     If you want to use different watcher class as default, set
     'OBSERVER_DEFAULT_WATCHER' in your settings.py
     """
-    watcher = settings.OBSERVER_DEFAULT_WATCHER(obj, attr, callback)
+    watcher_class = getattr(settings, 'OBSERVER_DEFAULT_WATCHER', ComplexWatcher)
+    watcher = watcher_class(obj, attr, callback)
     return watcher
+
+def unwatch_all():
+    """Shortcut method for unwatch all watcher"""
+    Watcher.unwatch_all()
